<?php
namespace Ep\Wp\Db;

use Options\Db\OptionsTableInterface;
use Laminas\Db\Sql\Predicate;
use Laminas\Db\TableGateway\TableGateway;

/**
 * Tablica s postavkama.
 *
 * @package Ep\Wp\Db
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link http://gitlab.ep.local/ep-framework/wordpress
 */
class OptionsTable extends TableGateway implements OptionsTableInterface
{
    /** @var array */
    private $options = [];

    /**
     * Vraća postavku s datim imenom.
     *
     * @param string $name
     *
     * @return mixed
     */
    public function getOption(string $name)
    {
        if (array_key_exists($name, $this->options)) {
            return $this->options[$name];
        }

        $options = $this->getOptions([$name]);
        return $options[$name] ?? [];
    }

    /**
     * Sprema postavku u bazu.
     *
     * @param string $name
     * @param mixed $value
     */
    public function setOption(string $name, $value): void
    {
        $update = $this->getSql()->update();
        $update
            ->set([
                'option_name' => $name,
                'option_value' => is_scalar($value) ? $value : serialize($value),
            ])
            ->where(new Predicate\Operator('option_name', Predicate\Operator::OP_EQ, $name));

        $this->updateWith($update);
    }

    /**
     * Vraća više postavki s datim imenima.
     *
     * @param array $names
     *
     * @return mixed[]
     */
    public function getOptions(array $names): array
    {
        $options = [];
        $filteredNames = [];

        foreach ($names as $name) {
            if (array_key_exists($name, $this->options)) {
                $options[$name] = $this->options[$name];
            } else {
                $filteredNames[] = $name;
            }
        }

        $select = $this->getSql()->select();
        $select->where(new Predicate\In('option_name', $filteredNames));

        $rows = $this->selectWith($select);

        foreach ($rows as $row) {
            $value = @unserialize($row['option_value']);

            if ($value === false) {
                $options[$row['option_name']] = $row['option_value'];
            } else {
                $options[$row['option_name']] = $value;
            }
        }

        return $options;
    }
}
