<?php
namespace Ep\Wp\View\Helper;

use Ep\Expressive\Flash\FlashMessage;
use Ep\Expressive\Flash\FlashMessageInterface;
use Mezzio\Flash\FlashMessagesInterface;
use Laminas\View\Helper\AbstractHelper;

/**
 * Renderira poruke iz FlashMessengera.
 *
 * @package Ep\Wp\View\Helper
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link http://gitlab.ep.local/ep-framework/wordpress
 */
final class Messages extends AbstractHelper
{
    /** @var FlashMessagesInterface */
    private $messages;

    /**
     * Messages constructor.
     * @param FlashMessagesInterface $messages
     */
    public function __construct(FlashMessagesInterface $messages)
    {
        $this->messages = $messages;
    }

    /**
     * Renderira poruke.
     *
     * @return string
     */
    public function __invoke(): string
    {
        $messages = $this->getMessages();

        if (0 === count($messages) || null === $this->view) {
            return '';
        }

        return $this->view->render('@wp/admin/messages.html.twig', [
            'messages' => $messages,
        ]);
    }

    /**
     * Vraća poruke za rendanje.
     *
     * @return FlashMessageInterface[]
     */
    private function getMessages(): array
    {
        $messages = [];

        foreach ($this->messages->getFlashes() as $message) {
            if (is_string($message)) {
                $message = new FlashMessage($message, 'updated');
            }

            $messages[] = $message;
        }

        return $messages;
    }
}
