<?php
namespace Ep\Wp;

use Interop\Container\ContainerInterface;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Class WordPressFactory
 *
 * @package Ep\Wp\Middleware
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class WordPressFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return object
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $container->get('config') ?? [];

        $db = $config['db'] ?? [];

        if (isset($db['default_adapter'])) {
            $db = $db['adapters'][$db['default_adapter']];
        }

        $plugins = $container->get('wp.plugin_loader');
        $shortcodes = $container->get('wp.shortcode_loader');
        $translations = $container->get('wp.translation_loader');

        return new WordPress($config ?? [], $db, $plugins, $shortcodes, $translations);
    }
}
